==> nextcloud-16.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/federatedfilesharing/l10n/en_GB.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Do you want to add the remote share {name} from {owner}@{remote}?",
    "Remote share" : "Remote share",
    "Remote share password" : "Remote share password",
    "Cancel" : "Cancel",
    "Add remote share" : "Add remote share",
    "Copy" : "Copy",
    "Copied!" : "Copied!",
    "Not supported!" : "Not supported!",
    "Press ⌘-C to copy." : "Press ⌘-C to copy.",
    "Press Ctrl-C to copy." : "Press Ctrl-C to copy.",
    "Invalid Federated Cloud ID" : "Invalid Federated Cloud ID",
    "Server to server sharing is not enabled on this server" : "Server to server sharing is not enabled on this server",
    "Couldn't establish a federated share." : "Couldn't establish a federated share.",
    "Couldn't establish a federated share, maybe the password was wrong." : "Couldn't establish a federated share, maybe the password was wrong.",
    "Federated Share request sent, you will receive an invitation. Check your notifications." : "Federated Share request sent, you will receive an invitation. Check your notifications.",
    "Couldn't establish a federated share, it looks like the server to federate with is too old (Nextcloud <= 9)." : "Couldn't establish a federated share, it looks like the server to federate with is too old (Nextcloud <= 9).",
    "Not allowed to create a federated share with the same user" : "Not allowed to create a federated share with the same user",
    "File is already shared with %s" : "File is already shared with %s",
    "Could not find share" : "Could not find share",
    "Federated sharing" : "Federated sharing",
    "You received \"%3$s\" as a remote share from %1$s (on behalf of %2$s)" : "You received \"%3$s\" as a remote share from %1$s (on behalf of %2$s)",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "You received {share} as a remote share from {user} (on behalf of {behalf})",
    "You received \"%3$s\" as a remote share from %1$s" : "You received \"%3$s\" as a remote share from %1$s",
    "You received {share} as a remote share from {user}" : "You received {share} as a remote share from {user}",
    "Accept" : "Accept",
    "Decline" : "Decline",
    "Share with me through my #Nextcloud Federated Cloud ID, see %s" : "Share with me through my #Nextcloud Federated Cloud ID, see %s",
    "Share with me through my #Nextcloud Federated Cloud ID" : "Share with me through my #Nextcloud Federated Cloud ID",
    "Sharing" : "Sharing",
    "Federated file sharing" : "Federated file sharing",
    "Federated Cloud Sharing" : "Federated Cloud Sharing",
    "Open documentation" : "Open documentation",
    "Adjust how people can share between servers." : "Adjust how people can share between servers.",
    "Allow users on this server to send shares to other servers" : "Allow users on this server to send shares to other servers",
    "Allow users on this server to receive shares from other servers" : "Allow users on this server to receive shares from other servers",
    "Search global and public address book for users" : "Search global and public address book for users",
    "Allow users to publish their data to a global and public address book" : "Allow users to publish their data to a global and public address book",
    "Federated Cloud" : "Federated Cloud",
    "Your Federated Cloud ID:" : "Your Federated Cloud ID:",
    "Share it so your friends can share files with you:" : "Share it so your friends can share files with you:",
    "Add to your website" : "Add to your website",
    "Share with me via Nextcloud" : "Share with me via Nextcloud",
    "HTML Code:" : "HTML Code:",
    "Sharing %s failed, because this item is already shared with %s" : "Sharing %s failed, because this item is already shared with %s",
    "Sharing %s failed, could not find %s, maybe the server is currently unreachable or uses a self-signed certificate." : "Sharing %s failed, could not find %s, maybe the server is currently unreachable or uses a self-signed certificate."
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-20.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/federatedfilesharing/l10n/en_GB.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Do you want to add the remote share {name} from {owner}@{remote}?",
    "Remote share" : "Remote share",
    "Remote share password" : "Remote share password",
    "Cancel" : "Cancel",
    "Add remote share" : "Add remote share",
    "Copy" : "Copy",
    "Copied!" : "Copied!",
    "Not supported!" : "Not supported!",
    "Press ⌘-C to copy." : "Press ⌘-C to copy.",
    "Press Ctrl-C to copy." : "Press Ctrl-C to copy.",
    "Invalid Federated Cloud ID" : "Invalid Federated Cloud ID",
    "Server to server sharing is not enabled on this server" : "Server to server sharing is not enabled on this server",
    "Couldn't establish a federated share." : "Couldn't establish a federated share.",
    "Couldn't establish a federated share, maybe the password was wrong." : "Couldn't establish a federated share, maybe the password was wrong.",
    "Federated Share request sent, you will receive an invitation. Check your notifications." : "Federated Share request sent, you will receive an invitation. Check your notifications.",
    "Couldn't establish a federated share, it looks like the server to federate with is too old (Nextcloud <= 9)." : "Couldn't establish a federated share, it looks like the server to federate with is too old (Nextcloud <= 9).",
    "Not allowed to create a federated share with the same user" : "Not allowed to create a federated share with the same user",
    "File is already shared with %s" : "File is already shared with %s",
    "Could not find share" : "Could not find share",
    "Federated sharing" : "Federated sharing",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "You received {share} as a remote share from {user} (on behalf of {behalf})",
    "You received {share} as a remote share from {user}" : "You received {share} as a remote share from {user}",
    "Accept" : "Accept",
    "Decline" : "Decline",
    "Share with me through my #Nextcloud Federated Cloud ID, see %s" : "Share with me through my #Nextcloud Federated Cloud ID, see %s",
    "Share with me through my #Nextcloud Federated Cloud ID" : "Share with me through my #Nextcloud Federated Cloud ID",
    "Sharing" : "Sharing",
    "Federated file sharing" : "Federated file sharing",
    "Provide federated file sharing across servers" : "Provide federated file sharing across servers",
    "Federated Cloud Sharing" : "Federated Cloud Sharing",
    "Open documentation" : "Open documentation",
    "Adjust how people can share between servers." : "Adjust how people can share between servers.",
    "Allow users on this server to receive shares from other servers" : "Allow users on this server to receive shares from other servers",
    "Search global and public address book for users" : "Search global and public address book for users",
    "Allow users to publish their data to a global and public address book" : "Allow users to publish their data to a global and public address book",
    "Federated Cloud" : "Federated Cloud",
    "Your Federated Cloud ID:" : "Your Federated Cloud ID:",
    "Share it so your friends can share files with you:" : "Share it so your friends can share files with you:",
    "Add to your website" : "Add to your website",
    "Share with me via Nextcloud" : "Share with me via Nextcloud",
    "HTML Code:" : "HTML Code:",
    "You received \"%3$s\" as a remote share from %1$s (on behalf of %2$s)" : "You received \"%3$s\" as a remote share from %1$s (on behalf of %2$s)",
    "You received \"%3$s\" as a remote share from %1$s" : "You received \"%3$s\" as a remote share from %1$s",
    "Allow users on this server to send shares to other servers" : "Allow users on this server to send shares to other servers"
},
"nplurals=2; plural=(n != 1);");
